@@ -1,3 +1,4 @@
+import html
 from typing import Any, Iterable, List, NamedTuple, Optional, Union
 
 import htmlgenerator as hg
@@ -13,7 +14,7 @@ from .button import Button
 from .icon import Icon
 from .overflow_menu import OverflowMenu
 from .pagination import Pagination, PaginationConfig
-from .search import Search, SearchBackendConfig
+from .search import Search
 
 
 class DataTable(hg.TABLE):
@@ -109,7 +110,7 @@ class DataTable(hg.TABLE):
         rowvariable: str = "row",
         spacing: str = "default",
         zebra: bool = False,
-        **kwargs: dict,
+        **kwargs: Any,
     ):
         """A carbon DataTable element
 
@@ -139,10 +140,10 @@ class DataTable(hg.TABLE):
         title: Any,
         helper_text: Any = None,
         primary_button: Optional[Button] = None,
-        search_backend: Optional[SearchBackendConfig] = None,
-        bulkactions: List[Link] = (),
+        bulkactions: Iterable[Link] = (),
         pagination_config: Optional[PaginationConfig] = None,
-        checkbox_for_bulkaction_name="_selected",
+        checkbox_for_bulkaction_name: str = "_selected",
+        search_urlparameter: Optional[str] = None,
         settingspanel: Any = None,
     ):
         """
@@ -150,16 +151,16 @@ class DataTable(hg.TABLE):
         title: table title
         helper_text: sub title
         primary_button: bread.layout.button.Button instance
-        search_backend: search endpoint
         bulkactions: List of bread.utils.links.Link instances. Will send a post or a get (depending on its "method" attribute) to the target url the sent data will be a form with the selected checkboxes as fields if the head-checkbox has been selected only that field will be selected
         """
         checkboxallid = f"datatable-check-{hg.html_id(self)}"
-        header = [hg.H4(title, _class="bx--data-table-header__title")]
+        header: List[hg.BaseElement] = [
+            hg.H4(title, _class="bx--data-table-header__title")
+        ]
         if helper_text is not None:
             header.append(
                 hg.P(helper_text, _class="bx--data-table-header__description")
             )
-        resultcontainerid = f"datatable-search-{hg.html_id(self)}"
         bulkactionlist = []
         for link in bulkactions:
             bulkactionlist.append(
@@ -256,17 +257,7 @@ class DataTable(hg.TABLE):
                     aria_label=_("Table Action Bar"),
                 ),
                 hg.DIV(
-                    hg.DIV(
-                        Search(
-                            widgetattributes={"autofocus": True},
-                            backend=search_backend,
-                            resultcontainerid=resultcontainerid,
-                            show_result_container=False,
-                        ),
-                        _class="bx--toolbar-search-container-persistent",
-                    )
-                    if search_backend
-                    else None,
+                    searchbar(search_urlparameter) if search_urlparameter else None,
                     Button(
                         icon="settings--adjust",
                         buttontype="ghost",
@@ -279,13 +270,6 @@ class DataTable(hg.TABLE):
                 ),
                 _class="bx--table-toolbar",
             ),
-            hg.DIV(
-                hg.DIV(
-                    id=resultcontainerid,
-                    style="width: 100%; position: absolute; z-index: 999",
-                ),
-                style="width: 100%; position: relative",
-            ),
             hg.DIV(
                 hg.DIV(
                     hg.DIV(
@@ -311,22 +295,22 @@ class DataTable(hg.TABLE):
         model,
         queryset=None,
         # column behaviour
-        columns: List[Union[str, "DataTableColumn"]] = None,
+        columns: Iterable[Union[str, "DataTableColumn"]] = (),
         prevent_automatic_sortingnames=False,
         # row behaviour
         rowvariable="row",
-        rowactions: List[Link] = (),
+        rowactions: Iterable[Link] = (),
         rowactions_dropdown=False,
         rowclickaction=None,
         # bulkaction behaviour
-        bulkactions: List[Link] = (),
+        bulkactions: Iterable[Link] = (),
         checkbox_for_bulkaction_name="_selected",
         # toolbar configuration
         title=None,
         primary_button: Optional[Button] = None,
         settingspanel: Any = None,
-        search_backend: Optional[SearchBackendConfig] = None,
         pagination_config: Optional[PaginationConfig] = None,
+        search_urlparameter: Optional[str] = None,
         **kwargs,
     ):
         """TODO: Write Docs!!!!
@@ -342,11 +326,6 @@ class DataTable(hg.TABLE):
                               datatable after creation.
         """
         columns = columns or filter_fieldlist(model, ["__all__"])
-        for col in columns:
-            if not (isinstance(col, DataTableColumn) or isinstance(col, str)):
-                raise ValueError(
-                    f"Argument 'columns' needs to be of a List[str] or a List[DataTableColumn], but found {col}"
-                )
 
         title = title or pretty_modelname(model, plural=True)
 
@@ -363,7 +342,7 @@ class DataTable(hg.TABLE):
             )
 
         if rowactions_dropdown:
-            objectactions_menu = OverflowMenu(
+            objectactions_menu: hg.HTMLElement = OverflowMenu(
                 rowactions,
                 flip=True,
                 item_attributes={"_class": "bx--table-row--menu-option"},
@@ -389,7 +368,11 @@ class DataTable(hg.TABLE):
         queryset = model.objects.all() if queryset is None else queryset
         column_definitions: List[DataTableColumn] = []
         for col in columns:
-            td_attributes = None
+            if not (isinstance(col, DataTableColumn) or isinstance(col, str)):
+                raise ValueError(
+                    f"Argument 'columns' needs to be of a List[str] or a List[DataTableColumn], but found {col}"
+                )
+            td_attributes: Optional[dict] = None
             if rowclickaction and getattr(col, "enable_row_click", True):
                 assert isinstance(
                     rowclickaction, Link
@@ -409,7 +392,7 @@ class DataTable(hg.TABLE):
                 )
             else:
                 if td_attributes:
-                    col = col._replace(td_attributes=td_attributes)
+                    col = col._replace(td_attributes=td_attributes)  # type: ignore
 
             column_definitions.append(col)
 
@@ -450,10 +433,10 @@ class DataTable(hg.TABLE):
                 model._meta.verbose_name_plural,
             ),
             primary_button=primary_button,
-            search_backend=search_backend,
             bulkactions=bulkactions,
             pagination_config=pagination_config,
             checkbox_for_bulkaction_name=checkbox_for_bulkaction_name,
+            search_urlparameter=search_urlparameter,
             settingspanel=settingspanel,
         )
 
@@ -501,8 +484,8 @@ class DataTableColumn(NamedTuple):
     cell: Any
     sortingname: Optional[str] = None
     enable_row_click: bool = True
-    th_attributes: hg.F = None
-    td_attributes: hg.F = None
+    th_attributes: Optional[Union[hg.F, dict]] = None
+    td_attributes: Optional[Union[hg.F, dict]] = None
 
     @staticmethod
     def from_modelfield(
@@ -539,12 +522,55 @@ class DataTableColumn(NamedTuple):
                     sortingclass_for_column(orderingurlparameter, self.sortingname),
                 ),
                 data_event="sort",
-                title=self.header,
                 **sortinglink_for_column(orderingurlparameter, self.sortingname),
             )
         return hg.TH(headcontent, lazy_attributes=self.th_attributes)
 
 
+def searchbar(search_urlparameter: str):
+    """
+    Creates a searchbar element for datatables to submit an entered search
+    term via a GET url parameter
+    """
+    searchinput = Search(
+        widgetattributes={
+            "autofocus": True,
+            "name": search_urlparameter,
+            "value": hg.F(
+                lambda c: html.escape(c["request"].GET.get(search_urlparameter, ""))
+            ),
+            "onfocus": "this.setSelectionRange(this.value.length, this.value.length);",
+        }
+    )
+    searchinput.close_button.attributes[
+        "onclick"
+    ] = "this.closest('form').querySelector('input').value = ''; this.closest('form').submit()"
+
+    return hg.DIV(
+        hg.FORM(
+            searchinput,
+            hg.Iterator(
+                hg.C("request").GET.lists(),
+                "urlparameter",
+                hg.If(
+                    hg.F(lambda c: c["urlparameter"][0] != search_urlparameter),
+                    hg.Iterator(
+                        hg.C("urlparameter")[1],
+                        "urlvalue",
+                        hg.INPUT(
+                            type="hidden",
+                            name=hg.C("urlparameter")[0],
+                            value=hg.C("urlvalue"),
+                        ),
+                    ),
+                ),
+            ),
+            method="GET",
+        ),
+        _class="bx--toolbar-search-container-persistent",
+    )
+
+
 def sortingclass_for_column(orderingurlparameter, columnname):
     def extracturlparameter(context):
         value = context["request"].GET.get(orderingurlparameter, "")
